==> scribe-pen-2.4.5-sources.jar: org/smallmind/scribe/pen/FileSizeRolloverRule.java <==
/*
 * Copyright (c) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 David Berkman
 * 
 * This file is part of the SmallMind Code Project.
 * 
 * The SmallMind Code Project is free software, you can redistribute
 * it and/or modify it under either, at your discretion...
 * 
 * 1) The terms of GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 * 
 * ...or...
 * 
 * 2) The terms of the Apache License, Version 2.0.
 * 
 * The SmallMind Code Project is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License or Apache License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * and the Apache License along with the SmallMind Code Project. If not, see
 * <http://www.gnu.org/licenses/> or <http://www.apache.org/licenses/LICENSE-2.0>.
 * 
 * Additional permission under the GNU Affero GPL version 3 section 7
 * ------------------------------------------------------------------
 * If you modify this Program, or any covered work, by linking or
 * combining it with other code, such other code is not for that reason
 * alone subject to any of the requirements of the GNU Affero GPL
 * version 3.
 */
package org.smallmind.scribe.pen;

import java.io.File;

public class FileSizeRolloverRule implements RolloverRule {

  private FileSizeQuantifier fileSizeQuantifier;
  private long maxSize;

  public FileSizeRolloverRule () {

    this(10, FileSizeQuantifier.MEGABYTES);
  }

  public FileSizeRolloverRule (long maxSize, FileSizeQuantifier fileSizeQuantifier) {

    super();

    this.maxSize = maxSize;
    this.fileSizeQuantifier = fileSizeQuantifier;
  }

  public long getMaxSize () {

    return maxSize;
  }

  public void setMaxSize (long maxSize) {

    this.maxSize = maxSize;
  }

  public FileSizeQuantifier getFileSizeQuantifier () {

    return fileSizeQuantifier;
  }

  public void setFileSizeQuantifier (FileSizeQuantifier fileSizeQuantifier) {

    this.fileSizeQuantifier = fileSizeQuantifier;
  }

  public boolean willRollover (File logFile, long bytesToBeWritten) {

    return (logFile.length() + bytesToBeWritten) > (maxSize * fileSizeQuantifier.getMultiplier());
  }
}

==> scribe-pen-3.3.11-sources.jar: org/smallmind/scribe/pen/FileSizeRolloverRule.java <==
/*
 * Copyright (c) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018 David Berkman
 * 
 * This file is part of the SmallMind Code Project.
 * 
 * The SmallMind Code Project is free software, you can redistribute
 * it and/or modify it under either, at your discretion...
 * 
 * 1) The terms of GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 * 
 * ...or...
 * 
 * 2) The terms of the Apache License, Version 2.0.
 * 
 * The SmallMind Code Project is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License or Apache License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * and the Apache License along with the SmallMind Code Project. If not, see
 * <http://www.gnu.org/licenses/> or <http://www.apache.org/licenses/LICENSE-2.0>.
 * 
 * Additional permission under the GNU Affero GPL version 3 section 7
 * ------------------------------------------------------------------
 * If you modify this Program, or any covered work, by linking or
 * combining it with other code, such other code is not for that reason
 * alone subject to any of the requirements of the GNU Affero GPL
 * version 3.
 */
package org.smallmind.scribe.pen;

public class FileSizeRolloverRule implements RolloverRule {

  private FileSizeQuantifier fileSizeQuantifier;
  private long maxSize;

  public FileSizeRolloverRule () {

    this(10, FileSizeQuantifier.MEGABYTES);
  }

  public FileSizeRolloverRule (long maxSize, FileSizeQuantifier fileSizeQuantifier) {

    super();

    this.maxSize = maxSize;
    this.fileSizeQuantifier = fileSizeQuantifier;
  }

  public long getMaxSize () {

    return maxSize;
  }

  public void setMaxSize (long maxSize) {

    this.maxSize = maxSize;
  }

  public FileSizeQuantifier getFileSizeQuantifier () {

    return fileSizeQuantifier;
  }

  public void setFileSizeQuantifier (FileSizeQuantifier fileSizeQuantifier) {

    this.fileSizeQuantifier = fileSizeQuantifier;
  }

  public boolean willRollover (long fileSize, long lastModified, long bytesToBeWritten) {

    return (fileSize + bytesToBeWritten) > (maxSize * fileSizeQuantifier.getMultiplier());
  }
}
